@@ -1,13 +1,41 @@
 package Pod::Weaver::Section::Name;
-{
-  $Pod::Weaver::Section::Name::VERSION = '3.101637';
-}
+# ABSTRACT: add a NAME section with abstract (for your Perl module)
+$Pod::Weaver::Section::Name::VERSION = '4.013';
 use Moose;
 with 'Pod::Weaver::Role::Section';
-# ABSTRACT: add a NAME section with abstract (for your Perl module)
+with 'Pod::Weaver::Role::StringFromComment';
 
-use Moose::Autobox;
+#pod =head1 OVERVIEW
+#pod
+#pod This section plugin will produce a hunk of Pod giving the name of the document
+#pod as well as an abstract, like this:
+#pod
+#pod   =head1 NAME
+#pod
+#pod   Some::Document - a document for some
+#pod
+#pod It will determine the name and abstract by inspecting the C<ppi_document> which
+#pod must be given.  It looks for comments in the form:
+#pod
+#pod
+#pod   # ABSTRACT: a document for some
+#pod   # PODNAME: Some::Package::Name
+#pod
+#pod If no C<PODNAME> comment is present, but a package declaration can be found,
+#pod the package name will be used as the document name.
+#pod
+#pod =attr header
+#pod
+#pod The title of the header to be added.
+#pod (default: "NAME")
+#pod
+#pod =cut
 
+has header => (
+  is      => 'ro',
+  isa     => 'Str',
+  default => 'NAME',
+);
 
 use Pod::Elemental::Element::Pod5::Command;
 use Pod::Elemental::Element::Pod5::Ordinary;
@@ -24,10 +52,7 @@ sub _get_docname_via_statement {
 sub _get_docname_via_comment {
   my ($self, $ppi_document) = @_;
 
-  return $self->_extract_comment_content(
-    $ppi_document,
-    qr/^\s*#+\s*PODNAME:\s*(.+)$/m,
-  );
+  return $self->_extract_comment_content($ppi_document, 'PODNAME');
 }
 
 sub _get_docname {
@@ -44,10 +69,7 @@ sub _get_docname {
 sub _get_abstract {
   my ($self, $input) = @_;
 
-  my $comment = $self->_extract_comment_content(
-    $input->{ppi_document},
-    qr/^\s*#+\s*ABSTRACT:\s*(.+)$/m,
-  );
+  my $comment = $self->_extract_comment_content($input->{ppi_document}, 'ABSTRACT');
 
   return $comment if $comment;
 
@@ -58,25 +80,6 @@ sub _get_abstract {
   return $abstract;
 }
 
-sub _extract_comment_content {
-  my ($self, $ppi_document, $regex) = @_;
-
-  my $content;
-  my $finder = sub {
-    my $node = $_[1];
-    return 0 unless $node->isa('PPI::Token::Comment');
-    if ( $node->content =~ $regex ) {
-      $content = $1;
-      return 1;
-    }
-    return 0;
-  };
-
-  $ppi_document->find_first($finder);
-
-  return $content;
-}
-
 sub weave_section {
   my ($self, $document, $input) = @_;
 
@@ -85,7 +88,7 @@ sub weave_section {
   my $docname  = $self->_get_docname($input);
   my $abstract = $self->_get_abstract($input);
 
-  Carp::croak sprintf "couldn't determine document name for %s", $filename
+  Carp::croak sprintf "couldn't determine document name for %s\nAdd something like this to %s:\n# PODNAME: bobby_tables.pl", $filename, $filename
     unless $docname;
 
   $self->log([ "couldn't find abstract in %s", $filename ]) unless $abstract;
@@ -95,27 +98,31 @@ sub weave_section {
 
   my $name_para = Pod::Elemental::Element::Nested->new({
     command  => 'head1',
-    content  => 'NAME',
+    content  => $self->header,
     children => [
       Pod::Elemental::Element::Pod5::Ordinary->new({ content => $name }),
     ],
   });
 
-  $document->children->push($name_para);
+  push @{ $document->children }, $name_para;
 }
 
+__PACKAGE__->meta->make_immutable;
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Pod::Weaver::Section::Name - add a NAME section with abstract (for your Perl module)
 
 =head1 VERSION
 
-version 3.101637
+version 4.013
 
 =head1 OVERVIEW
 
@@ -135,16 +142,22 @@ must be given.  It looks for comments in the form:
 If no C<PODNAME> comment is present, but a package declaration can be found,
 the package name will be used as the document name.
 
+=head1 ATTRIBUTES
+
+=head2 header
+
+The title of the header to be added.
+(default: "NAME")
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
